@@ -103,8 +103,11 @@ sub analyze_dependencies {
 
 sub download_module {
     my ( $self, $module, $config ) = @_;
-    if(defined $config->{global}->{use_minicpan} && $config->{global}->{use_minicpan}) {
-       $self->downloader->use_minicpan;
+    # REFACTOR
+    # move to this to BUILD method after implementing config as singleton
+    # class
+    if(defined $config->{global}->{cpan_mirrors} && $config->{global}->{cpan_mirrors}) {
+        $self->downloader->set_cpan_mirrors($config->{global}->{cpan_mirrors}); 
     }
 
     $self->{__downloaded} ||= {};
